==> haskell-zlib-bindings-0.1.1.5-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-7IzeFoAdSHzBhJZpKlLYHI
key:                  zlib-bindings-0.1.1.5-7IzeFoAdSHzBhJZpKlLYHI
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  2548f6e268637d5afd53d378d2b711bf
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-7IzeFoAdSHzBhJZpKlLYHI
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    zlib-0.6.3.0-8yAGwyuZ2uAGq492iT1L3K

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-bindings-0.1.1.5-139-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-9iZY3C7ng4WKhTRUshlsgi
key:                  zlib-bindings-0.1.1.5-9iZY3C7ng4WKhTRUshlsgi
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  aef99c9ac1780f3a36788a5165a251d0
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-9iZY3C7ng4WKhTRUshlsgi
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    zlib-0.6.3.0-5MlrrAbgjA8AXbUw8xgJze

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
